@@ -18,8 +18,11 @@
 abstract class Swift
 {
   
+  static $initialized = false;
+  static $initPath;
+  
   /** Swift Mailer Version number generated during dist release process */
-  const VERSION = '4.0.6';
+  const VERSION = '4.1.0';
   
   /**
    * Internal autoloader for spl_autoload_register().
@@ -29,16 +32,22 @@ abstract class Swift
   public static function autoload($class)
   {
     //Don't interfere with other autoloaders
-    if (0 !== strpos($class, 'Swift'))
+    if (0 !== strpos($class, 'Swift_'))
     {
-      return false;
+      return;
     }
 
     $path = dirname(__FILE__).'/'.str_replace('_', '/', $class).'.php';
 
     if (!file_exists($path))
     {
-      return false;
+      return;
+    }
+
+    if (self::$initPath && !self::$initialized)
+    {
+      self::$initialized = true;
+      require self::$initPath;
     }
 
     require_once $path;
@@ -48,9 +57,12 @@ abstract class Swift
    * Configure autoloading using Swift Mailer.
    * 
    * This is designed to play nicely with other autoloaders.
+   *
+   * @param string $initPath The init script to load when autoloading the first Swift class
    */
-  public static function registerAutoload()
+  public static function registerAutoload($initPath = null)
   {
+    self::$initPath = $initPath;
     spl_autoload_register(array('Swift', 'autoload'));
   }
   
